#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.container.contained import Contained
from zope.interface import implementer, provider
from zope.schema.fieldproperty import FieldProperty

from onf_website.shared.leisure.interfaces import ILeisure, ILeisureInfo, IWfLeisure, IWfLeisureFactory, \
    LEISURE_CONTENT_NAME, LEISURE_CONTENT_TYPE, LEISURE_INFO_ANNOTATIONS_KEY
from pyams_content.component.illustration import IIllustrationTarget, ILinkIllustrationTarget
from pyams_content.component.theme.interfaces import ITagsTarget, IThemesTarget
from pyams_content.features.preview.interfaces import IPreviewTarget
from pyams_content.features.review.interfaces import IReviewTarget
from pyams_content.shared.common import SharedContent, register_content_type
from pyams_content.shared.common.interfaces import IWfSharedContentFactory
from pyams_content.shared.common.types import WfTypedSharedContent
from pyams_utils.adapter import adapter_config, get_annotation_adapter
from pyams_utils.factory import factory_config


@implementer(IWfLeisure, IIllustrationTarget, ILinkIllustrationTarget, ITagsTarget, IThemesTarget,
             IPreviewTarget, IReviewTarget)
class WfLeisure(WfTypedSharedContent):
    """Leisure class"""

    content_type = LEISURE_CONTENT_TYPE
    content_name = LEISURE_CONTENT_NAME

    references = FieldProperty(IWfLeisure['references'])


register_content_type(WfLeisure)


@factory_config(ILeisureInfo)
class LeisureInfo(Persistent, Contained):
    """Leisure persistent information"""

    full = FieldProperty(ILeisureInfo['full'])
    favorite = FieldProperty(ILeisureInfo['favorite'])
    priority = FieldProperty(ILeisureInfo['priority'])


@adapter_config(context=IWfLeisure, provides=ILeisureInfo)
def leisure_info_factory(context):
    """Leisure info factory"""
    return get_annotation_adapter(context, LEISURE_INFO_ANNOTATIONS_KEY, ILeisureInfo,
                                  name='++info++')


@provider(IWfLeisureFactory)
@implementer(ILeisure)
class Leisure(SharedContent):
    """Workflow managed leisure"""


@adapter_config(context=IWfLeisureFactory, provides=IWfSharedContentFactory)
def leisure_content_factory(context):
    return WfLeisure
